@@ -3,7 +3,7 @@ BEGIN {
   $Spreadsheet::ParseXLSX::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Spreadsheet::ParseXLSX::VERSION = '0.12';
+  $Spreadsheet::ParseXLSX::VERSION = '0.13';
 }
 use strict;
 use warnings;
@@ -480,20 +480,26 @@ sub _parse_styles {
     } $styles->find_nodes('//fonts/font');
 
     my @format = map {
-        my $alignment = $_->first_child('alignment');
+        my $alignment  = $_->first_child('alignment');
+        my $protection = $_->first_child('protection');
         Spreadsheet::ParseExcel::Format->new(
             IgnoreFont         => !$_->att('applyFont'),
             IgnoreFill         => !$_->att('applyFill'),
             IgnoreBorder       => !$_->att('applyBorder'),
             IgnoreAlignment    => !$_->att('applyAlignment'),
             IgnoreNumberFormat => !$_->att('applyNumberFormat'),
+            IgnoreProtection   => !$_->att('applyProtection'),
 
             FontNo => 0+$_->att('fontId'),
             Font   => $font[$_->att('fontId')],
             FmtIdx => 0+$_->att('numFmtId'),
 
-            # Lock     => $iLock,
-            # Hidden   => $iHidden,
+            Lock => $protection
+                ? $protection->att('locked')
+                : 0,
+            Hidden => $protection
+                ? $protection->att('hidden')
+                : 0,
             # Style    => $iStyle,
             # Key123   => $i123,
             AlignH => $alignment
@@ -648,11 +654,9 @@ sub _color {
     my $self = shift;
     my ($colors, $color_node) = @_;
 
-    my $color; # XXX
-    if ($color_node) {
-        $color = '#000000' # XXX
-            if $color_node->att('auto');
-        $color = '#' . Spreadsheet::ParseExcel->ColorIdxToRGB( # XXX
+    my $color;
+    if ($color_node && !$color_node->att('auto')) {
+        $color = '#' . Spreadsheet::ParseExcel->ColorIdxToRGB(
             $color_node->att('indexed')
         ) if defined $color_node->att('indexed');
         $color = '#' . substr($color_node->att('rgb'), 2, 6)
@@ -697,7 +701,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -723,9 +727,52 @@ Parses an XLSX file. Parsing errors throw an exception. C<$file> can be either
 a filename or an open filehandle. Returns a
 L<Spreadsheet::ParseExcel::Workbook> instance containing the parsed data.
 
+=head1 INCOMPATIBILITIES
+
+This module returns data using classes from L<Spreadsheet::ParseExcel>, so for
+the most part, it should just be a drop-in replacement. That said, there are a
+couple areas where the data returned is intentionally different:
+
+=over 4
+
+=item Colors
+
+In Spreadsheet::ParseExcel, colors are represented by integers which index into
+the color table, and you have to use
+C<< Spreadsheet::ParseExcel->ColorIdxToRGB >> in order to get the actual value
+out. In Spreadsheet::ParseXLSX, while the color table still exists, cells are
+also allowed to specify their color directly rather than going through the
+color table. In order to avoid confusion, I normalize all color values in
+Spreadsheet::ParseXLSX to their string RGB format (C<"#0088ff">). This affects
+the C<Fill>, C<BdrColor>, and C<BdrDiag> properties of formats, and the
+C<Color> property of fonts. Note that the default color is represented by
+C<undef> (the same thing that C<ColorIdxToRGB> would return).
+
+=item Formulas
+
+Spreadsheet::ParseExcel doesn't support formulas. Spreadsheet::ParseXLSX
+provides basic formula support by returning the text of the formula as part of
+the cell data. You can access it via C<< $cell->{Formula} >>. Note that the
+restriction still holds that formula cell values aren't available unless they
+were explicitly provided when the spreadsheet was written.
+
+=back
+
 =head1 BUGS
 
-No known bugs.
+=over 4
+
+=item Worksheets without the C<dimension> tag are not supported
+
+=item Intra-cell formatting is discarded
+
+=item Diagonal border styles are ignored
+
+=back
+
+In addition, there are still a few areas which are not yet implemented (the
+XLSX spec is quite large). If you run into any of those, bug reports are quite
+welcome.
 
 Please report any bugs to GitHub Issues at
 L<https://github.com/doy/spreadsheet-parsexlsx/issues>.
@@ -780,7 +827,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Jesse Luehrs.
+This software is Copyright (c) 2014 by Jesse Luehrs.
 
 This is free software, licensed under:
 
